import { JsonController, Param, Body, Get, Post, Put, Delete, NotFoundError, OnUndefined, NotAcceptableError } from 'routing-controllers';
import { IsInt, IsNotEmpty, IsPositive, IsString } from 'class-validator';

/**
 * Error to throw when a runner couldn't be found.
 * Implemented this ways to work with the json-schema conversion for openapi.
 */
export class RunnerOrganisationNotFoundError extends NotFoundError {
	@IsString()
	name = "RunnerOrganisationNotFoundError"

	@IsString()
	message = "RunnerOrganisation not found!"
}

/**
 * Error to throw when two runners' ids don't match.
 * Usually occurs when a user tries to change a runner's id.
 * Implemented this ways to work with the json-schema conversion for openapi.
 */
export class RunnerOrganisationIdsNotMatchingError extends NotAcceptableError {
	@IsString()
	name = "RunnerOrganisationIdsNotMatchingError"

	@IsString()
	message = "The id's don't match!! \n And if you wanted to change a runner's id: This isn't allowed"
}